@@ -1,7 +1,5 @@
 package SQLite::Work;
-{
-  $SQLite::Work::VERSION = '0.14';
-}
+$SQLite::Work::VERSION = '0.15';
 use strict;
 use warnings;
 
@@ -11,7 +9,7 @@ SQLite::Work - report on and update an SQLite database.
 
 =head1 VERSION
 
-version 0.14
+version 0.15
 
 =head1 SYNOPSIS
 
@@ -661,6 +659,7 @@ sub do_report {
 	multi_page_template=>$multi_page_template,
 	outfile=>$outfile,
 	table_border=>1,
+	table_class=>'plain',
 	truncate_colnames=>0,
 	report_style=>'full',
 	link_suffix=>'.html',
@@ -872,6 +871,7 @@ sub do_multi_page_report {
 	row_template=>$row_template,
 	outfile=>$outfile,
 	table_border=>1,
+	table_class=>'plain',
 	truncate_colnames=>0,
 	report_style=>'full',
 	link_suffix=>'.html',
@@ -2127,6 +2127,7 @@ $my report = $self->format_report(
 	report_style=>'compact',
 	table_header=>$thead,
 	table_border=>1,
+	table_class=>'plain',
 	truncate_colnames=>0,
     );
 
@@ -2161,6 +2162,7 @@ sub format_report {
     my $table2 = $args{table2};
     my $report_style = $args{report_style};
     my $table_border = $args{table_border};
+    my $table_class = $args{table_class};
     my $truncate_colnames = $args{truncate_colnames};
 
     # change things depending on report_style
@@ -2175,6 +2177,17 @@ sub format_report {
 	    $table_border = 1;
 	}
     }
+    if (!defined $table_class)
+    {
+	if ($report_style eq 'bare')
+	{
+	    $table_class = '';
+	}
+	else
+	{
+	    $table_class = 'plain';
+	}
+    }
     if (!defined $truncate_colnames)
     {
 	if ($report_style eq 'full')
@@ -2317,7 +2330,8 @@ sub format_report {
 	if ($new_section)
 	{
 	    push @out, $self->start_section(type=>$args{layout},
-					  table_border=>$table_border);
+					  table_border=>$table_border,
+                                          table_class=>$table_class);
 	    if ($report_style ne 'bare'
 		and $args{layout} eq 'table')
 	    {
@@ -2518,11 +2532,14 @@ sub set_nice_cols {
 =head2 start_section
 
 $sect = $self->start_section(type=>'table',
-    table_border=>$table_border);
+    table_border=>$table_border,
+    table_class=>$table_class);
 
 Start a new table/para/list
 The 'table_border' option is the border-size of the table
 if using table style
+The 'table_class' option is the class of the table
+if using table style
 
 =cut
 sub start_section {
@@ -2535,7 +2552,9 @@ sub start_section {
 
     if ($args{type} eq 'table')
     {
-	return '<table border="' . $args{table_border} . '" class="plain">';
+        return sprintf('<table%s%s>',
+                       ($args{table_border} ? ' border="' . $args{table_border} . '"' : ''),
+                       ($args{table_class} ? ' class="' . $args{table_class} . '"' : ''));
     }
     elsif ($args{type} eq 'para')
     {
